#ifndef QUICKTIME_V410_H
#define QUICKTIME_V410_H

// 8 bit YUVA 4444

extern void quicktime_init_codec_v408(quicktime_video_map_t *);

#endif
